# This package
A standalone Python wrapper for [MrSEQL](https://github.com/lnthach/Mr-SEQL)

## Installation

## Installation using pip
pip install mrseql

## Installation from source
```
git clone https://github.com/mlgig/mrseql.git

cd mrseql

pip install .
```

## Paper
>  T. L. Nguyen, S. Gsponer, I. Ilie, M. O'reilly and G. Ifrim [Interpretable Time Series Classification using Linear Models and Multi-resolution Multi-domain Symbolic Representations](https://www.researchgate.net/publication/332875865_Interpretable_Time_Series_Classification_using_Linear_Models_and_Multi-resolution_Multi-domain_Symbolic_Representations) in Data Mining and Knowledge Discovery (DMKD), May 2019, https://doi.org/10.1007/s10618-019-00633-3

